/*
 * Copyright (C) 2021-2022 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "shared/source/xe_hpc_core/hw_cmds_xe_hpc_core_base.h"
using Family = NEO::XeHpcCoreFamily;
constexpr static auto gfxCore = IGFX_XE_HPC_CORE;
#include "opencl/source/sampler/sampler_tgllp_and_later.inl"
